@@ -8,5 +8,5 @@ logging.basicConfig(
 logger = logging.getLogger(__name__)
 
 
-__version__ = "0.1.12"
-__all__ = "AccQsure"
+__version__ = "0.1.18"
+__all__ = ("AccQsure",)
